@@ -9,11 +9,11 @@
 
 #include "kimap_export.h"
 
-#include "job.h"
 #include "imapset.h"
+#include "job.h"
 
-namespace KIMAP {
-
+namespace KIMAP
+{
 class MoveJobPrivate;
 
 /**
