@@ -1,60 +1,57 @@
 /**
-  * This file is part of the KDE project
-  * SPDX-FileCopyrightText: 2009 Kevin Ottens <ervin@kde.org>
-  * SPDX-FileCopyrightText: 2009 Andras Mantia <amantia@kde.org>
-  *
-  * SPDX-License-Identifier: LGPL-2.0-or-later
-  */
+ * This file is part of the KDE project
+ * SPDX-FileCopyrightText: 2009 Kevin Ottens <ervin@kde.org>
+ * SPDX-FileCopyrightText: 2009 Andras Mantia <amantia@kde.org>
+ *
+ * SPDX-License-Identifier: LGPL-2.0-or-later
+ */
 
-#include <QDebug>
-#include <QTcpSocket>
 #include <QCoreApplication>
-#include <QSignalSpy>
+#include <QDebug>
 
 #include "acl.h"
-#include "session.h"
 #include "appendjob.h"
 #include "capabilitiesjob.h"
+#include "closejob.h"
+#include "createjob.h"
+#include "deleteacljob.h"
+#include "deletejob.h"
+#include "expungejob.h"
 #include "fetchjob.h"
+#include "getacljob.h"
+#include "getmetadatajob.h"
 #include "listjob.h"
+#include "listrightsjob.h"
 #include "loginjob.h"
 #include "logoutjob.h"
-#include "selectjob.h"
-#include "closejob.h"
-#include "expungejob.h"
-#include "createjob.h"
-#include "deletejob.h"
+#include "myrightsjob.h"
 #include "namespacejob.h"
-#include "subscribejob.h"
-#include "unsubscribejob.h"
 #include "renamejob.h"
-#include "storejob.h"
+#include "selectjob.h"
+#include "session.h"
 #include "sessionuiproxy.h"
 #include "setacljob.h"
-#include "getacljob.h"
-#include "deleteacljob.h"
-#include "myrightsjob.h"
-#include "listrightsjob.h"
 #include "setmetadatajob.h"
-#include "getmetadatajob.h"
+#include "storejob.h"
+#include "subscribejob.h"
+#include "unsubscribejob.h"
 
 using namespace KIMAP;
 
-using PartsReceivedSignal = void(FetchJob::*)(const QString &, const QMap<qint64,qint64> &,
-                                              const QMap<qint64, MessageParts> &);
+using PartsReceivedSignal = void (FetchJob::*)(const QString &, const QMap<qint64, qint64> &, const QMap<qint64, MessageParts> &);
 
-using HeadersReceivedSignal = void(FetchJob::*)(const QString &,
-                                                const QMap<qint64, qint64> &,
-                                                const QMap<qint64, qint64> &,
-                                                const QMap<qint64, MessageFlags> &,
-                                                const QMap<qint64, MessagePtr> &);
+using HeadersReceivedSignal = void (FetchJob::*)(const QString &,
+                                                 const QMap<qint64, qint64> &,
+                                                 const QMap<qint64, qint64> &,
+                                                 const QMap<qint64, MessageFlags> &,
+                                                 const QMap<qint64, MessagePtr> &);
 
-class UiProxy: public SessionUiProxy
+class UiProxy : public SessionUiProxy
 {
 public:
     bool ignoreSslError(const KSslErrorUiData &errorData) override
     {
-        Q_UNUSED(errorData);
+        Q_UNUSED(errorData)
         return true;
     }
 };
@@ -82,7 +79,7 @@ void dumpContentHelper(KMime::Content *part, const QString &partId = QString())
 
 void listFolders(Session *session, bool includeUnsubscribed = false, const QString &nameFilter = QLatin1String(""))
 {
-    auto *list = new ListJob(session);
+    auto list = new ListJob(session);
     list->setIncludeUnsubscribed(includeUnsubscribed);
     list->exec();
     Q_ASSERT_X(list->error() == 0, "ListJob", list->errorString().toLocal8Bit().constData());
@@ -93,17 +90,16 @@ void listFolders(Session *session, bool includeUnsubscribed = false, const QStri
             qDebug() << descriptor.separator << descriptor.name;
         }
     }
-
 }
 
 void testMetaData(Session *session)
 {
     qDebug() << "TESTING: METADATA commands";
-    auto *create = new CreateJob(session);
+    auto create = new CreateJob(session);
     create->setMailBox(QStringLiteral("INBOX/TestFolder"));
     create->exec();
 
-    auto *setmetadata = new SetMetaDataJob(session);
+    auto setmetadata = new SetMetaDataJob(session);
     setmetadata->setMailBox(QStringLiteral("INBOX/TestFolder"));
     setmetadata->setServerCapability(SetMetaDataJob::Annotatemore);
     setmetadata->setEntry("/comment");
@@ -117,16 +113,18 @@ void testMetaData(Session *session)
     setmetadata->addMetaData("value.priv", "true");
     setmetadata->exec();
 
-    auto *getmetadata = new GetMetaDataJob(session);
+    auto getmetadata = new GetMetaDataJob(session);
     getmetadata->setMailBox(QStringLiteral("INBOX/TestFolder"));
     getmetadata->setServerCapability(SetMetaDataJob::Annotatemore);
     getmetadata->addEntry("/*", "value.priv");
     getmetadata->exec();
-    Q_ASSERT_X(getmetadata->metaData(QLatin1String("INBOX/TestFolder"), "/check", "value.priv") == "true", "",  "/check metadata should be true");
-    Q_ASSERT_X(getmetadata->metaData(QLatin1String("INBOX/TestFolder"), "/comment", "value.priv") == "My new comment", "",  "/check metadata should be My new comment");
+    Q_ASSERT_X(getmetadata->metaData(QLatin1String("INBOX/TestFolder"), "/check", "value.priv") == "true", "", "/check metadata should be true");
+    Q_ASSERT_X(getmetadata->metaData(QLatin1String("INBOX/TestFolder"), "/comment", "value.priv") == "My new comment",
+               "",
+               "/check metadata should be My new comment");
 
-    //cleanup
-    auto *deletejob = new DeleteJob(session);
+    // cleanup
+    auto deletejob = new DeleteJob(session);
     deletejob->setMailBox(QLatin1String("INBOX/TestFolder"));
     deletejob->exec();
 }
@@ -134,11 +132,11 @@ void testMetaData(Session *session)
 void testAcl(Session *session, const QString &user)
 {
     qDebug() << "TESTING: ACL commands";
-    auto *create = new CreateJob(session);
+    auto create = new CreateJob(session);
     create->setMailBox(QStringLiteral("INBOX/TestFolder"));
     create->exec();
 
-    auto *listRights = new ListRightsJob(session);
+    auto listRights = new ListRightsJob(session);
     listRights->setMailBox(QStringLiteral("INBOX/TestFolder"));
     listRights->setIdentifier(user.toLatin1());
     listRights->exec();
@@ -150,7 +148,7 @@ void testAcl(Session *session, const QString &user)
     }
     qDebug() << "Possible rights on INBOX/TestFolder: " << strList;
 
-    auto *myRights = new MyRightsJob(session);
+    auto myRights = new MyRightsJob(session);
     myRights->setMailBox(QStringLiteral("INBOX/TestFolder"));
     myRights->exec();
 
@@ -159,7 +157,7 @@ void testAcl(Session *session, const QString &user)
     qDebug() << "Reading INBOX/TestFolder is possible: " << myRights->hasRightEnabled(Acl::Read);
     Q_ASSERT_X(myRights->hasRightEnabled(Acl::Read), "Reading INBOX is NOT possible", "");
 
-    auto *getAcl = new GetAclJob(session);
+    auto getAcl = new GetAclJob(session);
     getAcl->setMailBox(QStringLiteral("INBOX/TestFolder"));
     getAcl->exec();
     qDebug() << "Anyone rights on INBOX/TestFolder: " << getAcl->rights("anyone");
@@ -169,7 +167,7 @@ void testAcl(Session *session, const QString &user)
 
     qDebug() << "Removing Delete right ";
     mine = Acl::Delete;
-    auto *setAcl = new SetAclJob(session);
+    auto setAcl = new SetAclJob(session);
     setAcl->setMailBox(QStringLiteral("INBOX/TestFolder"));
     setAcl->setIdentifier(user.toLatin1());
     setAcl->setRights(AclJobBase::Remove, mine);
@@ -195,8 +193,8 @@ void testAcl(Session *session, const QString &user)
     users = getAcl->rights(user.toLatin1());
     qDebug() << user << " rights on INBOX/TestFolder: " << Acl::rightsToString(users);
 
-    //cleanup
-    auto *deletejob = new DeleteJob(session);
+    // cleanup
+    auto deletejob = new DeleteJob(session);
     deletejob->setMailBox(QStringLiteral("INBOX/TestFolder"));
     deletejob->exec();
 }
@@ -204,8 +202,8 @@ void testAcl(Session *session, const QString &user)
 void testAppendAndStore(Session *session)
 {
     qDebug() << "TESTING: APPEND and STORE";
-    //setup
-    auto *create = new CreateJob(session);
+    // setup
+    auto create = new CreateJob(session);
     create->setMailBox(QStringLiteral("INBOX/TestFolder"));
     create->exec();
 
@@ -221,35 +219,40 @@ void testAppendAndStore(Session *session)
         "Hello Joe, do you think we can meet at 3:30 tomorrow?\r\n";
 
     qDebug() << "Append a message in INBOX/TestFolder...";
-    auto *append = new AppendJob(session);
+    auto append = new AppendJob(session);
     append->setMailBox(QStringLiteral("INBOX/TestFolder"));
     append->setContent(testMailContent);
     append->exec();
     Q_ASSERT_X(append->error() == 0, "AppendJob", append->errorString().toLocal8Bit().constData());
 
     qDebug() << "Read the message back and compare...";
-    auto *select = new SelectJob(session);
+    auto select = new SelectJob(session);
     select->setMailBox(QStringLiteral("INBOX/TestFolder"));
     select->exec();
 
-    auto *fetch = new FetchJob(session);
+    auto fetch = new FetchJob(session);
     FetchJob::FetchScope scope;
     fetch->setSequenceSet(ImapSet(1));
     scope.parts.clear();
     scope.mode = FetchJob::FetchScope::Content;
     fetch->setScope(scope);
     MessagePtr message;
-    QObject::connect(fetch, static_cast<HeadersReceivedSignal>(&FetchJob::headersReceived),
-                     fetch, [&](const QString &, const QMap<qint64, qint64> &,
-                                const QMap<qint64, qint64> &, const QMap<qint64, MessageFlags> &,
-                                const QMap<qint64, MessagePtr> &msgs) {
-                        message = msgs[1];
-                    });
+    QObject::connect(fetch,
+                     static_cast<HeadersReceivedSignal>(&FetchJob::headersReceived),
+                     fetch,
+                     [&](const QString &,
+                         const QMap<qint64, qint64> &,
+                         const QMap<qint64, qint64> &,
+                         const QMap<qint64, MessageFlags> &,
+                         const QMap<qint64, MessagePtr> &msgs) {
+                         message = msgs[1];
+                     });
     fetch->exec();
     Q_ASSERT_X(fetch->error() == 0, "FetchJob", fetch->errorString().toLocal8Bit().constData());
     testMailContent.replace("\r\n", "\n");
     Q_ASSERT_X(testMailContent == message->head() + "\n" + message->body(),
-               "Message differs from reference", QByteArray(message->head() + "\n" + message->body()).constData());
+               "Message differs from reference",
+               QByteArray(message->head() + "\n" + message->body()).constData());
 
     fetch = new FetchJob(session);
     fetch->setSequenceSet(ImapSet(1));
@@ -257,19 +260,23 @@ void testAppendAndStore(Session *session)
     scope.mode = FetchJob::FetchScope::Flags;
     fetch->setScope(scope);
     MessageFlags expectedFlags;
-    QObject::connect(fetch, static_cast<HeadersReceivedSignal>(&FetchJob::headersReceived),
-                     fetch, [&](const QString &, const QMap<qint64, qint64> &,
-                                const QMap<qint64, qint64> &, const QMap<qint64, MessageFlags> &flags,
-                                const QMap<qint64, MessagePtr> &) {
-                        expectedFlags = flags[1];
-                    });
+    QObject::connect(fetch,
+                     static_cast<HeadersReceivedSignal>(&FetchJob::headersReceived),
+                     fetch,
+                     [&](const QString &,
+                         const QMap<qint64, qint64> &,
+                         const QMap<qint64, qint64> &,
+                         const QMap<qint64, MessageFlags> &flags,
+                         const QMap<qint64, MessagePtr> &) {
+                         expectedFlags = flags[1];
+                     });
     fetch->exec();
     qDebug() << "Read the message flags:" << expectedFlags;
 
     qDebug() << "Add the \\Deleted flag...";
     expectedFlags << "\\Deleted";
     std::sort(expectedFlags.begin(), expectedFlags.end());
-    auto *store = new StoreJob(session);
+    auto store = new StoreJob(session);
     store->setSequenceSet(ImapSet(1));
     store->setMode(StoreJob::AppendFlags);
     store->setFlags(QList<QByteArray>() << "\\Deleted");
@@ -287,8 +294,8 @@ void testAppendAndStore(Session *session)
     select->setMailBox(QStringLiteral("INBOX"));
     select->exec();
 
-    //cleanup
-    auto *deletejob = new DeleteJob(session);
+    // cleanup
+    auto deletejob = new DeleteJob(session);
     deletejob->setMailBox(QStringLiteral("INBOX/TestFolder"));
     deletejob->exec();
     deletejob = new DeleteJob(session);
@@ -299,17 +306,17 @@ void testAppendAndStore(Session *session)
 void testRename(Session *session)
 {
     qDebug() << "TESTING: RENAME";
-    //setup
-    auto *create = new CreateJob(session);
+    // setup
+    auto create = new CreateJob(session);
     create->setMailBox(QStringLiteral("INBOX/TestFolder"));
     create->exec();
 
     qDebug() << "Listing mailboxes with name TestFolder:";
     listFolders(session, true, QStringLiteral("TestFolder"));
 
-    //actual tests
+    // actual tests
     qDebug() << "Renaming to RenamedTestFolder";
-    auto *rename = new RenameJob(session);
+    auto rename = new RenameJob(session);
     rename->setSourceMailBox(QStringLiteral("INBOX/TestFolder"));
     rename->setDestinationMailBox(QStringLiteral("INBOX/RenamedTestFolder"));
     rename->exec();
@@ -319,8 +326,8 @@ void testRename(Session *session)
     qDebug() << "Listing mailboxes with name RenamedTestFolder:";
     listFolders(session, true, QStringLiteral("RenamedTestFolder"));
 
-    //cleanup
-    auto *deletejob = new DeleteJob(session);
+    // cleanup
+    auto deletejob = new DeleteJob(session);
     deletejob->setMailBox(QStringLiteral("INBOX/TestFolder"));
     deletejob->exec();
     deletejob = new DeleteJob(session);
@@ -331,17 +338,17 @@ void testRename(Session *session)
 void testSubscribe(Session *session)
 {
     qDebug() << "TESTING: SUBSCRIBE/UNSUBSCRIBE";
-    //setup
-    auto *create = new CreateJob(session);
+    // setup
+    auto create = new CreateJob(session);
     create->setMailBox(QStringLiteral("INBOX/TestFolder"));
     create->exec();
 
     qDebug() << "Listing  subscribed mailboxes with name TestFolder:";
     listFolders(session, false, QStringLiteral("TestFolder"));
 
-    //actual tests
+    // actual tests
     qDebug() << "Subscribing to INBOX/TestFolder";
-    auto *subscribe = new SubscribeJob(session);
+    auto subscribe = new SubscribeJob(session);
     subscribe->setMailBox(QStringLiteral("INBOX/TestFolder"));
     subscribe->exec();
 
@@ -349,15 +356,15 @@ void testSubscribe(Session *session)
     listFolders(session, false, QStringLiteral("TestFolder"));
 
     qDebug() << "Unsubscribing from INBOX/TestFolder";
-    auto *unsubscribe = new UnsubscribeJob(session);
+    auto unsubscribe = new UnsubscribeJob(session);
     unsubscribe->setMailBox(QStringLiteral("INBOX/TestFolder"));
     unsubscribe->exec();
 
     qDebug() << "Listing  subscribed mailboxes with name TestFolder:";
     listFolders(session, false, QStringLiteral("TestFolder"));
 
-    //cleanup
-    auto *deletejob = new DeleteJob(session);
+    // cleanup
+    auto deletejob = new DeleteJob(session);
     deletejob->setMailBox(QStringLiteral("INBOX/TestFolder"));
     deletejob->exec();
 }
@@ -366,7 +373,7 @@ void testDelete(Session *session)
 {
     qDebug() << "TESTING: DELETE";
     qDebug() << "Creating INBOX/TestFolder:";
-    auto *create = new CreateJob(session);
+    auto create = new CreateJob(session);
     create->setMailBox(QStringLiteral("INBOX/TestFolder"));
     create->exec();
 
@@ -374,7 +381,7 @@ void testDelete(Session *session)
     listFolders(session, true, QStringLiteral("TestFolder"));
 
     qDebug() << "Deleting INBOX/TestFolder";
-    auto *deletejob = new DeleteJob(session);
+    auto deletejob = new DeleteJob(session);
     deletejob->setMailBox(QStringLiteral("INBOX/TestFolder"));
     deletejob->exec();
 
@@ -409,9 +416,9 @@ int main(int argc, char **argv)
     session.setUiProxy(proxy);
 
     qDebug() << "Logging in...";
-    auto *login = new LoginJob(&session);
-    //login->setEncryptionMode( LoginJob::TlsV1 );
-    //login->setAuthenticationMode( LoginJob::Plain );
+    auto login = new LoginJob(&session);
+    // login->setEncryptionMode( LoginJob::TlsV1 );
+    // login->setAuthenticationMode( LoginJob::Plain );
     login->setUserName(user);
     login->setPassword(password);
     login->exec();
@@ -433,7 +440,7 @@ int main(int argc, char **argv)
     qDebug() << "Server greeting:" << session.serverGreeting();
 
     qDebug() << "Asking for capabilities:";
-    auto *capabilities = new CapabilitiesJob(&session);
+    auto capabilities = new CapabilitiesJob(&session);
     capabilities->exec();
     Q_ASSERT_X(capabilities->error() == 0, "CapabilitiesJob", capabilities->errorString().toLocal8Bit().constData());
     Q_ASSERT(session.state() == Session::Authenticated);
@@ -441,7 +448,7 @@ int main(int argc, char **argv)
     qDebug();
 
     qDebug() << "Asking for namespaces:";
-    auto *namespaces = new NamespaceJob(&session);
+    auto namespaces = new NamespaceJob(&session);
     namespaces->exec();
     Q_ASSERT_X(namespaces->error() == 0, "CapabilitiesJob", namespaces->errorString().toLocal8Bit().constData());
     Q_ASSERT(session.state() == Session::Authenticated);
@@ -449,17 +456,20 @@ int main(int argc, char **argv)
     qDebug() << "Contains empty namespace:" << namespaces->containsEmptyNamespace();
 
     qDebug() << "Personal:";
-    foreach (MailBoxDescriptor ns, namespaces->personalNamespaces()) {
+    const auto personalNamespaces = namespaces->personalNamespaces();
+    for (MailBoxDescriptor ns : personalNamespaces) {
         qDebug() << ns.separator << ns.name;
     }
 
     qDebug() << "User:    ";
-    foreach (MailBoxDescriptor ns, namespaces->userNamespaces()) {
+    const auto userNamespaces = namespaces->userNamespaces();
+    for (MailBoxDescriptor ns : userNamespaces) {
         qDebug() << ns.separator << ns.name;
     }
 
     qDebug() << "Shared:  ";
-    foreach (MailBoxDescriptor ns, namespaces->sharedNamespaces()) {
+    const auto sharedNamespaces = namespaces->sharedNamespaces();
+    for (MailBoxDescriptor ns : sharedNamespaces) {
         qDebug() << ns.separator << ns.name;
     }
     qDebug();
@@ -469,7 +479,7 @@ int main(int argc, char **argv)
     Q_ASSERT(session.state() == Session::Authenticated);
 
     qDebug() << "Selecting INBOX:";
-    auto *select = new SelectJob(&session);
+    auto select = new SelectJob(&session);
     select->setMailBox(QStringLiteral("INBOX"));
     select->exec();
     Q_ASSERT_X(select->error() == 0, "SelectJob", select->errorString().toLocal8Bit().constData());
@@ -484,7 +494,7 @@ int main(int argc, char **argv)
     qDebug();
 
     qDebug() << "Fetching first 3 messages headers:";
-    auto *fetch = new FetchJob(&session);
+    auto fetch = new FetchJob(&session);
     FetchJob::FetchScope scope;
     fetch->setSequenceSet(ImapSet(1, 3));
     scope.parts.clear();
@@ -493,18 +503,22 @@ int main(int argc, char **argv)
     QMap<qint64, qint64> sizes;
     QMap<qint64, MessagePtr> messages;
 
-    QObject::connect(fetch, static_cast<HeadersReceivedSignal>(&FetchJob::headersReceived),
-                     fetch, [&](const QString &, const QMap<qint64,qint64> &,
-                                const QMap<qint64, qint64> &sizes_,
-                                const QMap<qint64, MessageFlags> &,
-                                const QMap<qint64, MessagePtr> &msgs_) {
+    QObject::connect(fetch,
+                     static_cast<HeadersReceivedSignal>(&FetchJob::headersReceived),
+                     fetch,
+                     [&](const QString &,
+                         const QMap<qint64, qint64> &,
+                         const QMap<qint64, qint64> &sizes_,
+                         const QMap<qint64, MessageFlags> &,
+                         const QMap<qint64, MessagePtr> &msgs_) {
                          sizes = sizes_;
                          messages = msgs_;
                      });
     fetch->exec();
     Q_ASSERT_X(fetch->error() == 0, "FetchJob", fetch->errorString().toLocal8Bit().constData());
     Q_ASSERT(session.state() == Session::Selected);
-    foreach (qint64 id, messages.keys()) {
+    const auto messagesKey = messages.keys();
+    for (qint64 id : messagesKey) {
         qDebug() << "* Message" << id << "(" << sizes[id] << "bytes )";
         qDebug() << "  From      :" << messages[id]->from()->asUnicodeString();
         qDebug() << "  To        :" << messages[id]->to()->asUnicodeString();
@@ -521,17 +535,21 @@ int main(int argc, char **argv)
     scope.mode = FetchJob::FetchScope::Flags;
     fetch->setScope(scope);
     QMap<qint64, MessageFlags> flags;
-    QObject::connect(fetch, static_cast<HeadersReceivedSignal>(&FetchJob::headersReceived),
-                     fetch, [&](const QString &, const QMap<qint64,qint64> &,
-                                const QMap<qint64, qint64> &,
-                                const QMap<qint64, MessageFlags> &flags_,
-                                const QMap<qint64, MessagePtr> &) {
+    QObject::connect(fetch,
+                     static_cast<HeadersReceivedSignal>(&FetchJob::headersReceived),
+                     fetch,
+                     [&](const QString &,
+                         const QMap<qint64, qint64> &,
+                         const QMap<qint64, qint64> &,
+                         const QMap<qint64, MessageFlags> &flags_,
+                         const QMap<qint64, MessagePtr> &) {
                          flags = flags_;
                      });
     fetch->exec();
     Q_ASSERT_X(fetch->error() == 0, "FetchJob", fetch->errorString().toLocal8Bit().constData());
     Q_ASSERT(session.state() == Session::Selected);
-    foreach (qint64 id, flags.keys()) {
+    const auto flagsKey = flags.keys();
+    for (qint64 id : flagsKey) {
         qDebug() << "* Message" << id << "flags:" << flags[id];
     }
     qDebug();
@@ -542,11 +560,14 @@ int main(int argc, char **argv)
     scope.parts.clear();
     scope.mode = FetchJob::FetchScope::Structure;
     fetch->setScope(scope);
-    QObject::connect(fetch, static_cast<HeadersReceivedSignal>(&FetchJob::headersReceived),
-                     fetch, [&](const QString &, const QMap<qint64,qint64> &,
-                                const QMap<qint64, qint64> &,
-                                const QMap<qint64, MessageFlags> &,
-                                const QMap<qint64, MessagePtr> &msgs_) {
+    QObject::connect(fetch,
+                     static_cast<HeadersReceivedSignal>(&FetchJob::headersReceived),
+                     fetch,
+                     [&](const QString &,
+                         const QMap<qint64, qint64> &,
+                         const QMap<qint64, qint64> &,
+                         const QMap<qint64, MessageFlags> &,
+                         const QMap<qint64, MessagePtr> &msgs_) {
                          messages = msgs_;
                      });
     fetch->exec();
@@ -564,18 +585,21 @@ int main(int argc, char **argv)
     scope.mode = FetchJob::FetchScope::Headers;
     fetch->setScope(scope);
     QMap<qint64, MessageParts> allParts;
-    QObject::connect(fetch, static_cast<PartsReceivedSignal>(&FetchJob::partsReceived),
-                     fetch, [&](const QString &, const QMap<qint64, qint64> &,
-                                const QMap<qint64, MessageParts> &parts_) {
+    QObject::connect(fetch,
+                     static_cast<PartsReceivedSignal>(&FetchJob::partsReceived),
+                     fetch,
+                     [&](const QString &, const QMap<qint64, qint64> &, const QMap<qint64, MessageParts> &parts_) {
                          allParts = parts_;
                      });
     fetch->exec();
     Q_ASSERT_X(fetch->error() == 0, "FetchJob", fetch->errorString().toLocal8Bit().constData());
     Q_ASSERT(session.state() == Session::Selected);
-    foreach (qint64 id, allParts.keys()) {
+    const auto allkeys = allParts.keys();
+    for (qint64 id : allkeys) {
         qDebug() << "* Message" << id << "parts headers";
         MessageParts parts = allParts[id];
-        foreach (const QByteArray &partId, parts.keys()) {
+        const auto parsKeys = parts.keys();
+        for (const QByteArray &partId : parsKeys) {
             qDebug() << "  ** Part" << partId;
             qDebug() << "     Name       :" << parts[partId]->contentType()->name();
             qDebug() << "     Mimetype   :" << parts[partId]->contentType()->mimeType();
@@ -591,17 +615,20 @@ int main(int argc, char **argv)
     scope.parts << "2";
     scope.mode = FetchJob::FetchScope::Content;
     fetch->setScope(scope);
-    QObject::connect(fetch, static_cast<PartsReceivedSignal>(&FetchJob::partsReceived),
-                     fetch, [&](const QString &, const QMap<qint64, qint64> &,
-                                const QMap<qint64, MessageParts> &parts_) {
+    QObject::connect(fetch,
+                     static_cast<PartsReceivedSignal>(&FetchJob::partsReceived),
+                     fetch,
+                     [&](const QString &, const QMap<qint64, qint64> &, const QMap<qint64, MessageParts> &parts_) {
                          allParts = parts_;
                      });
     fetch->exec();
     Q_ASSERT_X(fetch->error() == 0, "FetchJob", fetch->errorString().toLocal8Bit().constData());
     Q_ASSERT(session.state() == Session::Selected);
-    foreach (int id, allParts.keys()) {
+    const auto allpartskeys = allParts.keys();
+    for (int id : allpartskeys) {
         MessageParts parts = allParts[id];
-        foreach (const QByteArray &partId, parts.keys()) {
+        const auto partsKeys = parts.keys();
+        for (const QByteArray &partId : partsKeys) {
             qDebug() << "* Message" << id << "part" << partId << "content:";
             qDebug() << parts[partId]->body();
         }
@@ -621,17 +648,17 @@ int main(int argc, char **argv)
     testMetaData(&session);
 
     qDebug() << "Expunge INBOX:";
-    auto *expunge = new ExpungeJob(&session);
+    auto expunge = new ExpungeJob(&session);
     expunge->exec();
 
     qDebug() << "Closing INBOX:";
-    auto *close = new CloseJob(&session);
+    auto close = new CloseJob(&session);
     close->exec();
     Q_ASSERT(session.state() == Session::Authenticated);
     qDebug();
 
     qDebug() << "Logging out...";
-    auto *logout = new LogoutJob(&session);
+    auto logout = new LogoutJob(&session);
     logout->exec();
     Q_ASSERT_X(logout->error() == 0, "LogoutJob", logout->errorString().toLocal8Bit().constData());
     Q_ASSERT(session.state() == Session::Disconnected);
